import React, { useRef, useState } from "react";
import styles from "./index.less";
import { PageContainer } from '@ant-design/pro-layout';
import { PlusOutlined } from '@ant-design/icons';
import ProTable from '@ant-design/pro-table';
import { Button, Form, Input, DatePicker, Modal, Select, Popconfirm } from 'antd';
import cardAPI from "../service";

/**
 * 储值卡账户管理
 * @returns 
 */
const memberAccount = () => {
    const actionRef = useRef();
    const [modalForm] = Form.useForm();
    const [isModalOpen, setIsModalOpen] = useState(false);
    const [currentOption, setCurrentOption] = useState({ id: '' });
    const [current, setCurrent] = useState(1);
    const [pageSize, setPageSize] = useState(10);
    const [total, setTotal] = useState(0);

    /**
     * 点击编辑按钮
     * @param {*} record
     */
    const onEditTableRow = (record) => {
        setCurrentOption(record);
        setIsModalOpen(true);
        modalForm.setFieldsValue(record);
    }

    /**
     * 点击新建
     */
    const onCreateTableRow = () => {
        setIsModalOpen(true);
    }

    /**
     * 删除数据
     * @param {*} record 
     */
    const onDeleteTableRow = (record) => {
        console.log('删除', record)
    }

    /**
     * 提交表单
     */
    const onFinish = (values) => {
        console.log('value', values);
        if (values.id) {
            console.log('更新')
        } else {
            console.log('创建')
        }
    }

    const columns = [
        {
            title: 'ID',
            dataIndex: 'id',
            ellipsis: true,
        },
        {
            title: '姓名',
            dataIndex: 'name',
            ellipsis: true,
        },
        {
            title: '会员ID',
            dataIndex: 'memberInfoId',
            ellipsis: true,
        },
        // {
        //     disable: true,
        //     title: '状态',
        //     dataIndex: 'status',
        //     valueType: 'select',
        //     valueEnum: {
        //         0: {
        //             text: '禁用',
        //             status: 'Error',
        //         },
        //         1: {
        //             text: '正常',
        //             status: 'Success',
        //         },
        //         2: {
        //             text: '挂失',
        //             status: 'Error',
        //         },
        //         3: {
        //             text: '作废',
        //             status: 'Error',
        //         },
        //     },
        // },
        {
            title: '余额',
            dataIndex: 'money',
        },
        {
            title: '操作',
            valueType: 'option',
            key: 'option',
            render: (text, record, _, action) => [
                <a onClick={() => onEditTableRow(record)}>编辑</a>,
                <Popconfirm
                    title="你确定要删除此条数据吗？"
                    onConfirm={() => onDeleteTableRow(record)}
                    okText="确定"
                    cancelText="取消"
                >
                    <a href="#">删除</a>
                </Popconfirm>
            ],
        },
    ];


    return (
        <PageContainer>
            <div className={styles.member_card_container}>
                <ProTable
                    columns={columns}
                    actionRef={actionRef}
                    request={
                        async () => {
                            const response = await cardAPI.GetMemberAccountPageList({
                                current,
                                pageSize
                            });
                            setTotal(response.data.data);
                            return {
                                data: response.data.data,
                                success: true,
                                total: response.data.total,
                            }
                        }
                    }
                    cardBordered
                    editable={{
                        type: 'multiple',
                    }}
                    rowKey="id"
                    search={false}
                    options={{
                        setting: {
                            listsHeight: 400,
                        },
                    }}
                    pagination={{
                        pageSize: pageSize,
                        onChange: (page) => setCurrent(page)
                    }}
                    dateFormatter="string"
                    headerTitle="储值卡账户管理"
                    toolBarRender={() => [
                        <Button key="button" icon={<PlusOutlined />} type="primary" onClick={onCreateTableRow}>
                            新建
                        </Button>
                    ]}
                />
                <Modal width={600} title={currentOption.id ? '编辑会员' : '添加会员'} visible={isModalOpen} footer={false} onCancel={() => setIsModalOpen(false)}>
                    <Form
                        name="basic"
                        onFinish={onFinish}
                        form={modalForm}
                    >

                        <Form.Item
                            label="id"
                            name="id"
                            hidden={true}
                        >
                            <Input />
                        </Form.Item>

                        <Form.Item
                            label="姓名"
                            name="name"
                            rules={[
                                {
                                    required: true,
                                    message: '请输入姓名！',
                                },
                            ]}
                        >
                            <Input />
                        </Form.Item>

                        <Form.Item
                            label="会员ID"
                            name="cardId"
                            rules={[
                                {
                                    required: true,
                                    message: '请输入会员ID！',
                                },
                            ]}
                        >
                            <Input />
                        </Form.Item>

                        <Form.Item
                            label="状态"
                            name="status"
                            rules={[
                                {
                                    required: true,
                                    message: '请输入选择状态！',
                                },
                            ]}
                        >
                            <Select>
                                <Select.Option value={0}>禁用</Select.Option>
                                <Select.Option value={1}>正常</Select.Option>
                                <Select.Option value={2}>挂失</Select.Option>
                                <Select.Option value={3}>作废</Select.Option>
                            </Select>
                        </Form.Item>

                        <Form.Item
                            label="余额"
                            name="money"
                            rules={[
                                {
                                    required: true,
                                    message: '请输入余额！',
                                },
                            ]}
                        >
                            <Input />
                        </Form.Item>

                        <Form.Item>
                            <Button type="primary" htmlType="submit">
                                确定
                            </Button>
                        </Form.Item>
                    </Form>
                </Modal>
            </div>
        </PageContainer>
    )
}

export default memberAccount;